==> joptsimple_4.5.orig.tar.gz: jopt-simple-jopt-simple-4.5/src/test/java/joptsimple/OptionSetDetectedOptionsTest.java <==
/*
 The MIT License

 Copyright (c) 2004-2013 Paul R. Holser, Jr.

 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sublicense, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:

 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package joptsimple;

import static java.util.Arrays.*;

import org.junit.Test;

import static org.junit.Assert.*;

/**
 * @author <a href="mailto:pholser@alumni.rice.edu">Paul Holser</a>
 */
public class OptionSetDetectedOptionsTest extends AbstractOptionParserFixture {
    @Test
    public void givesSpecsInOrderOfCommandLinePresentation() {
        OptionSpec<Void> a = parser.accepts( "a" );
        OptionSpec<String> b = parser.accepts( "b" ).withRequiredArg();
        OptionSpec<String> c = parser.accepts( "c" ).withOptionalArg();
        OptionSpec<String> d = parser.accepts( "d" ).withRequiredArg().defaultsTo( "1" );
        OptionSpec<String> e = parser.accepts( "e" ).withOptionalArg().defaultsTo( "2" );

        OptionSet options = parser.parse( "-a", "-e", "-c", "5", "-d", "6", "-b", "4", "-d", "7", "-e", "8" );

        assertEquals( asList( a, e, c, d, b, d, e ), options.specs() );
    }
}

==> joptsimple_5.0.4.orig.tar.gz: jopt-simple-jopt-simple-5.0.4/src/test/java/joptsimple/OptionSetDetectedOptionsTest.java <==
/*
 The MIT License

 Copyright (c) 2004-2015 Paul R. Holser, Jr.

 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sublicense, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:

 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package joptsimple;

import java.util.Arrays;

import org.junit.Test;

import static org.junit.Assert.*;

/**
 * @author <a href="mailto:pholser@alumni.rice.edu">Paul Holser</a>
 */
public class OptionSetDetectedOptionsTest extends AbstractOptionParserFixture {
    @Test
    public void givesSpecsInOrderOfCommandLinePresentation() {
        OptionSpec<Void> a = parser.accepts( "a" );
        OptionSpec<String> b = parser.accepts( "b" ).withRequiredArg();
        OptionSpec<String> c = parser.accepts( "c" ).withOptionalArg();
        OptionSpec<String> d = parser.accepts( "d" ).withRequiredArg().defaultsTo( "1" );
        OptionSpec<String> e = parser.accepts( "e" ).withOptionalArg().defaultsTo( "2" );

        OptionSet options = parser.parse( "-a", "-e", "-c", "5", "-d", "6", "-b", "4", "-d", "7", "-e", "8" );

        assertEquals( Arrays.asList( a, e, c, d, b, d, e ), options.specs() );
    }
}
